@@ -1,6 +1,6 @@
 import os
 from dataclasses import dataclass, field
-from typing import Iterable, Optional, Callable, Tuple, Any, Sequence
+from typing import Iterable, Optional, Callable, Tuple, Sequence
 
 import torch
 from torch import nn
@@ -47,6 +47,9 @@ class ITask:
     def has_children(self) -> bool:
         return False
 
+    def is_train_only(self) -> bool:
+        return False
+
     def get_available_func(self):
         return self.available_func
 
@@ -101,7 +104,7 @@ class Task(ITask):
     activation: Optional[nn.Module]
     decoder: Decoder
     module: nn.Module
-    metrics: Tuple[str, TorchMetric]
+    metrics: Sequence[Tuple[str, TorchMetric]]
 
     def get_activation(self) -> Optional[nn.Module]:
         return self.activation
@@ -139,7 +142,7 @@ class BinaryHardcodedTask(Task):
     activation: Optional[nn.Module] = None
     decoder: Decoder = None
     module: nn.Module = Identity()
-    metrics: Tuple[str, TorchMetric] = ()
+    metrics: Sequence[Tuple[str, TorchMetric]] = ()
 
 
 @dataclass()
@@ -160,7 +163,7 @@ class BoundedRegressionTask(Task):
     activation: nn.Module = field(default_factory=lambda: nn.Sigmoid())
     decoder: Decoder = None
     inputs: Sequence = None
-    metrics: Tuple = field(default_factory=get_default_bounded_regression_metrics)
+    metrics: Sequence[Tuple[str, TorchMetric]] = field(default_factory=get_default_bounded_regression_metrics)
 
 
 @dataclass()
@@ -179,7 +182,7 @@ class BinaryClassificationTask(Task):
     activation: Optional[nn.Module] = nn.Sigmoid()
     decoder: Decoder = field(default_factory=BinaryDecoder)
     module: nn.Module = Identity()
-    metrics: Tuple[str, TorchMetric] = field(default_factory=get_default_binary_metrics)
+    metrics: Sequence[Tuple[str, TorchMetric]] = field(default_factory=get_default_binary_metrics)
 
 
 @dataclass
@@ -198,7 +201,7 @@ class ClassificationTask(Task):
     activation: Optional[nn.Module] = nn.Softmax()
     decoder: Decoder = field(default_factory=ClassificationDecoder)
     module: nn.Module = Identity()
-    metrics: Tuple[str, TorchMetric] = field(default_factory=get_default_classification_metrics)
+    metrics: Sequence[Tuple[str, TorchMetric]] = field(default_factory=get_default_classification_metrics)
 
 
 @dataclass()
@@ -217,7 +220,7 @@ class MultilabelClassificationTask(Task):
     activation: Optional[nn.Module] = nn.Sigmoid()
     decoder: Decoder = field(default_factory=MultilabelClassificationDecoder)
     module: nn.Module = Identity()
-    metrics: Tuple[str, TorchMetric] = field(default_factory=get_default_multilabel_classification_metrics)
+    metrics: Sequence[Tuple[str, TorchMetric]] = field(default_factory=get_default_multilabel_classification_metrics)
 
 
 class TaskFlow(ITask):
