@@ -24,8 +24,8 @@ def split_dataset(dataset, test_size=0.2, random_state=None):
 
 def train_test_val_split(df, random_state=None):
     train_indices, val_indices = split_dataset(df, test_size=0.2, random_state=random_state)
-    test_indices, val_indices = split_dataset(val_indices, test_size=0.5, random_state=random_state)
-    return train_indices, test_indices, val_indices
+    rel_test_indices, rel_val_indices = split_dataset(val_indices, test_size=0.5, random_state=random_state)
+    return train_indices, val_indices[rel_test_indices], val_indices[rel_val_indices]
 
 
 class TransformedSubset(Dataset):
